@@ -48,7 +48,7 @@ has 'distvname'           => ( is => 'rw' );
 has 'filename'            => ( is => 'rw' );
 has 'index' => ( is => 'rw', isa => 'CPAN::Mini::Webserver::Index' );
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 sub service_name {
     "$ENV{USER}'s minicpan_webserver";
@@ -187,10 +187,10 @@ sub _handle_request {
     $self->distvname($distvname);
     $self->filename($filename);
 
-    #warn "$raw / $download / $pauseid / $distvname / $filename";
+    # warn "$path / $raw / $download / $pauseid / $distvname / $filename";
 
     if ( $path eq '/' ) {
-        $self->direct_to_template("index");
+        $self->index_page();
     } elsif ( $path eq '/search/' ) {
         $self->search_page();
     } elsif ( $raw && $pauseid && $distvname && $filename ) {
@@ -236,6 +236,31 @@ sub _handle_request {
 
 }
 
+sub index_page {
+    my $self = shift;
+
+    my $recent_filename = file( $self->directory, 'RECENT' );
+    my @recent;
+    if ( -f $recent_filename ) {
+        my $fh = IO::File->new($recent_filename) || die $!;
+        while ( my $line = <$fh> ) {
+            chomp $line;
+            next unless $line =~ m{authors/id/};
+
+            my $d = CPAN::DistnameInfo->new($line);
+
+            push @recent, $d;
+        }
+    }
+    $self->send_http_header( 200, -charset => 'utf-8' );
+    print Template::Declare->show(
+        'index',
+        {   recents            => \@recent,
+            parse_cpan_authors => $self->parse_cpan_authors,
+        }
+    );
+}
+
 sub not_found_page {
     my $self = shift;
     my $q    = shift;
